package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.MallPosterSetting;

/**
 * 海报背景图Mapper接口
 *
 * @author ruoyi
 * @date 2023-11-07
 */
public interface MallPosterSettingMapper
{
    /**
     * 查询海报背景图
     *
     * @param posterId 海报背景图主键
     * @return 海报背景图
     */
    public MallPosterSetting selectMallPosterSettingByPosterId(Integer posterId);

    /**
     * 查询海报背景图列表
     *
     * @param mallPosterSetting 海报背景图
     * @return 海报背景图集合
     */
    public List<MallPosterSetting> selectMallPosterSettingList(MallPosterSetting mallPosterSetting);

    /**
     * 获取背景海报
     * @return 结果
     */
    public MallPosterSetting selectMallPosterSetting();

    /**
     * 新增海报背景图
     *
     * @param mallPosterSetting 海报背景图
     * @return 结果
     */
    public int insertMallPosterSetting(MallPosterSetting mallPosterSetting);

    /**
     * 修改海报背景图
     *
     * @param mallPosterSetting 海报背景图
     * @return 结果
     */
    public int updateMallPosterSetting(MallPosterSetting mallPosterSetting);

    /**
     * 删除海报背景图
     *
     * @param posterId 海报背景图主键
     * @return 结果
     */
    public int deleteMallPosterSettingByPosterId(Integer posterId);

    /**
     * 批量删除海报背景图
     *
     * @param posterIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMallPosterSettingByPosterIds(Integer[] posterIds);
}
